#[non_exhaustive]pub enum ErrorCode {
InactiveEffect,
MissingService,
TypeMismatch,
DuplicateService,
AccessDenied,
InvalidConfig,
Plugin,
Event,
PropertyConflict,
Other,
}Expand description
Stable, machine-readable Cordis error codes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InactiveEffect
An effect was created from a disposed or unloading context.
MissingService
A requested service does not exist in the current scope.
TypeMismatch
A dynamically stored value had an unexpected concrete Rust type.
DuplicateService
A service or property was registered more than once in one scope.
AccessDenied
A service was mutated by a fiber other than its provider.
InvalidConfig
Plugin configuration was rejected by its validator.
Plugin
Plugin startup failed.
Event
An event listener or middleware failed.
PropertyConflict
A property is already declared using another reflection mode.
Other
A general framework error.
Implementations